@@ -15,7 +15,7 @@ from .crawlers.Redgifs_Spider import RedGifsCrawler
 from .crawlers.ShareX_Spider import ShareXCrawler
 from .crawlers.Thotsbay_Spider import ThotsbayCrawler
 from .base_functions import log
-from .data_classes import CascadeItem
+from .data_classes import CascadeItem, AsyncRateLimiter
 
 
 class ScrapeMapper():
@@ -39,7 +39,6 @@ class ScrapeMapper():
         self.thotsbay_crawler = None
 
         self.semaphore = asyncio.Semaphore(1)
-        self.sharex_semaphore = asyncio.Semaphore(4)
         self.mapping = {"anonfiles.com": self.Anonfiles, "bunkr.is": self.Chibisafe,
                         "bunkr.to": self.Chibisafe, "coomer.party": self.coomer,
                         "cyberdrop.cc": self.Chibisafe, "cyberdrop.me": self.Chibisafe,
@@ -138,7 +137,10 @@ class ScrapeMapper():
     async def ShareX(self, url: URL, title=None):
         if not self.sharex_crawler:
             self.sharex_crawler = ShareXCrawler(include_id=self.include_id)
-        async with self.sharex_semaphore:
+        if "jpg.church" in url.host:
+            async with AsyncRateLimiter(19):
+                domain_obj = await self.sharex_crawler.fetch(self.session, url)
+        else:
             domain_obj = await self.sharex_crawler.fetch(self.session, url)
         if title:
             await domain_obj.append_title(title)
